/*
 * Copyright 2016 - 2024 Gary Talent (gary@drinkingtea.net). All rights reserved.
 */

#include <imgui.h>

#include <turbine/gfx.hpp>

#include <studio/imguiutil.hpp>

namespace studio::ig {

void centerNextWindow(turbine::Context &ctx) noexcept {
	auto const sz = turbine::getScreenSize(ctx);
	auto const screenW = static_cast<float>(sz.width);
	auto const screenH = static_cast<float>(sz.height);
	auto const mod = ImGui::GetWindowDpiScale() * 2;
	ImGui::SetNextWindowPos(ImVec2(screenW / mod, screenH / mod), ImGuiCond_Always, ImVec2(0.5f, 0.5f));
}

bool PushButton(ox::CStringView lbl, ImVec2 const&btnSz) noexcept {
	return ImGui::Button(lbl.c_str(), btnSz);
}

void PopupBtns(float popupWidth, bool &popupOpen) {
	constexpr auto btnSz = ImVec2{50, BtnSz.y};
	ImGui::Separator();
	ImGui::SetCursorPosX(popupWidth - 118);
	if (ImGui::Button("OK", btnSz)) {
		ImGui::CloseCurrentPopup();
		popupOpen = false;
	}
	ImGui::SameLine();
	if (ImGui::Button("Cancel", btnSz)) {
		ImGui::CloseCurrentPopup();
		popupOpen = false;
	}
}

bool ComboBox(
		ox::CStringView lbl,
		ox::SpanView<ox::String> list,
		size_t &selectedIdx) noexcept {
	bool out{};
	auto const first = selectedIdx < list.size() ? list[selectedIdx].c_str() : "";
	if (ImGui::BeginCombo(lbl.c_str(), first, 0)) {
		for (auto i = 0u; i < list.size(); ++i) {
			const auto selected = (selectedIdx == i);
			if (ImGui::Selectable(list[i].c_str(), selected) && selectedIdx != i) {
				selectedIdx = i;
				//oxLogError(m_model.setPalette(list[n]));
				out = true;
			}
		}
		ImGui::EndCombo();
	}
	return out;
}

}
